@@ -79,7 +79,8 @@ set_cron_watched(int fd) {
 		int w;
 
 		w = inotify_add_watch(fd, watchpaths[i],
-			IN_CLOSE_WRITE | IN_ATTRIB | IN_MOVED_TO | IN_MOVED_FROM | IN_MOVE_SELF | IN_DELETE);
+			IN_CREATE | IN_CLOSE_WRITE | IN_ATTRIB | IN_MODIFY | IN_MOVED_TO |
+			IN_MOVED_FROM | IN_MOVE_SELF | IN_DELETE | IN_DELETE_SELF);
 		if (w < 0) {
 			if (wd[i] != -1) {
         			log_it("CRON", pid, "This directory or file can't be watched", watchpaths[i], errno);
@@ -100,6 +101,27 @@ set_cron_watched(int fd) {
 }
 #endif
 
+static void
+handle_signals(cron_db *database) {
+	if (got_sighup) {
+		got_sighup = 0;
+#if defined WITH_INOTIFY
+		/* watches must be reinstated on reload */
+		if (inotify_enabled) {
+			set_cron_unwatched(database->ifd);
+			inotify_enabled = 0;
+		}
+#endif
+		database->mtime = (time_t) 0;
+		log_close();
+	}
+
+	if (got_sigchld) {
+		got_sigchld = 0;
+		sigchld_reaper();
+	}
+}
+
 static void
 usage(void) {
 	const char **dflags;
@@ -123,6 +145,8 @@ main(int argc, char *argv[]) {
 #endif
 
 	ProgramName = argv[0];
+	MailCmd[0] = '\0';
+	cron_default_mail_charset[0] = '\0';
 
 	setlocale(LC_ALL, "");
 
@@ -216,7 +240,8 @@ main(int argc, char *argv[]) {
 		wd[i] = -2;
 	}
 
-	fd = inotify_init();
+	database.ifd = fd = inotify_init();
+	fcntl(fd, F_SETFD, FD_CLOEXEC);
 	if (fd < 0)
 		log_it("CRON", pid, "INFO", "Inotify init failed", errno);
 	set_cron_watched(fd);
@@ -252,19 +277,19 @@ main(int argc, char *argv[]) {
 		 * clock.  Classify the change into one of 4 cases.
 		 */
 		timeDiff = timeRunning - virtualTime;
-		if (inotify_enabled) {
 #if defined WITH_INOTIFY
-			check_inotify_database(&database, fd);
-#endif
+		if (inotify_enabled) {
+			check_inotify_database(&database);
 		}
 		else {
-			load_database(&database);
-#if defined WITH_INOTIFY
-			/* try reinstating the watches */
-			set_cron_watched(fd);
-#endif			
+			if(load_database(&database))
+				/* try reinstating the watches */
+				set_cron_watched(fd);
 		}
-		
+#else
+		load_database(&database);
+#endif
+
 		/* shortcut for the most common case */
 		if (timeDiff == 1) {
 			virtualTime = timeRunning;
@@ -354,17 +379,7 @@ main(int argc, char *argv[]) {
 		/* Jobs to be run (if any) are loaded; clear the queue. */
 		job_runqueue();
 
-		/* Check to see if we received a signal while running jobs. */
-		if (got_sighup) {
-			got_sighup = 0;
-		if (!inotify_enabled)
-			database.mtime = (time_t) 0;
-			log_close();
-		}
-		if (got_sigchld) {
-			got_sigchld = 0;
-			sigchld_reaper();
-		}
+		handle_signals(&database);
 	}
 
 #if defined WITH_INOTIFY
@@ -380,6 +395,19 @@ static void
 run_reboot_jobs(cron_db *db) {
 	user *u;
 	entry *e;
+	int reboot;
+	pid_t pid = getpid();
+
+	/* lock exist - skip reboot jobs */
+	if (access(REBOOT_LOCK, F_OK)) {
+		log_it("CRON", pid, "INFO", "@reboot jobs will be run at computer's startup.", 0);
+		return;
+	}
+	/* lock doesn't exist - create lock, run reboot jobs */
+	if ((reboot = creat(REBOOT_LOCK, S_IRUSR&S_IWUSR)) < 0)
+		log_it("CRON", pid, "INFO", "Can't create lock for reboot jobs.", errno);
+	else
+		close(reboot);
 
 	for (u = db->head; u != NULL; u = u->next) {
 		for (e = u->crontab; e != NULL; e = e->next) {
@@ -398,6 +426,8 @@ find_jobs(int vtime, cron_db *db, int doWild, int doNonWild) {
 	int minute, hour, dom, month, dow;
 	user *u;
 	entry *e;
+    const char *uname;
+    struct passwd *pw = NULL;
 
 	/* make 0-based values out of these so we can use them as indicies
 	 */
@@ -434,21 +464,25 @@ find_jobs(int vtime, cron_db *db, int doWild, int doNonWild) {
 			Debug(DSCH|DEXT, ("user [%s:%ld:%ld:...] cmd=\"%s\"\n",
 			    e->pwd->pw_name, (long)e->pwd->pw_uid,
 			    (long)e->pwd->pw_gid, e->cmd))
-			job_tz = env_get("CRON_TZ", e->envp);
-			maketime(job_tz, orig_tz);
-			/* here we test whether time is NOW */
-			if (bit_test(e->minute, minute) &&
-			    bit_test(e->hour, hour) &&
-			    bit_test(e->month, month) &&
-			    ( ((e->flags & DOM_STAR) || (e->flags & DOW_STAR))
-			      ? (bit_test(e->dow,dow) && bit_test(e->dom,dom))
-			      : (bit_test(e->dow,dow) || bit_test(e->dom,dom))
-			    )
-			   ) {
-				if ((doNonWild &&
-				    !(e->flags & (MIN_STAR|HR_STAR))) || 
-				    (doWild && (e->flags & (MIN_STAR|HR_STAR))))
-					job_add(e, u);	/*will add job, if it isn't in queue already for NOW.*/
+            uname = e->pwd->pw_name;
+			/* check if user exists in time of job is being run f.e. ldap */
+			if ((pw = getpwnam(uname)) != NULL) {
+				job_tz = env_get("CRON_TZ", e->envp);
+				maketime(job_tz, orig_tz);
+				/* here we test whether time is NOW */
+				if (bit_test(e->minute, minute) &&
+			    	bit_test(e->hour, hour) &&
+				    bit_test(e->month, month) &&
+				    ( ((e->flags & DOM_STAR) || (e->flags & DOW_STAR))
+				      ? (bit_test(e->dow,dow) && bit_test(e->dom,dom))
+				      : (bit_test(e->dow,dow) || bit_test(e->dom,dom))
+			    	)
+				   ) {
+					if ((doNonWild &&
+					    !(e->flags & (MIN_STAR|HR_STAR))) || 
+					    (doWild && (e->flags & (MIN_STAR|HR_STAR))))
+							job_add(e, u);	/*will add job, if it isn't in queue already for NOW.*/
+					}
 			}
 		}
 	}
@@ -502,16 +536,8 @@ cron_sleep(int target, cron_db *db) {
 		 * If so, service the signal(s) then continue sleeping
 		 * where we left off.
 		 */
-		if (got_sighup) {
-			got_sighup = 0;
-			if (!inotify_enabled)
-				db->mtime = (time_t) 0;
-			log_close();
-		}
-		if (got_sigchld) {
-			got_sigchld = 0;
-			sigchld_reaper();
-		}
+		handle_signals(db);
+
 		t2 = time(NULL) + GMToff;
 		seconds_to_wait -= (int)(t2 - t1);
 		t1 = t2;
