@@ -93,6 +93,8 @@ main(int argc, char *argv[]) {
 	
 	Pid = getpid();
 	ProgramName = argv[0];
+	MailCmd[0] = '\0';
+	cron_default_mail_charset[0] = '\0';
 
 	setlocale(LC_ALL, "");
 
