@@ -20,10 +20,6 @@
  * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#if !defined(lint) && !defined(LINT)
-static char rcsid[] = "$Id: entry.c,v 1.17 2004/01/23 18:56:42 vixie Exp $";
-#endif
-
 /* vix 26jan87 [RCS'd; rest of log is in RCS file]
  * vix 01jan87 [added line-level error recovery]
  * vix 31dec86 [added /step to the from-to range, per bob@acornrc]
@@ -284,7 +280,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 			}
 			e->envp = tenvp;
 		} else
-			log_it("CRON", getpid(), "error", "can't set SHELL");
+			log_it("CRON", getpid(), "error", "can't set SHELL", 0);
 	}
 	if (!env_get("HOME", e->envp)) {
 		if (glue_strings(envstr, sizeof envstr, "HOME",
@@ -295,7 +291,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 			}
 			e->envp = tenvp;
 		} else
-			log_it("CRON", getpid(), "error", "can't set HOME");
+			log_it("CRON", getpid(), "error", "can't set HOME", 0);
 	}
 #ifndef LOGIN_CAP
 	/* If login.conf is in used we will get the default PATH later. */
@@ -308,7 +304,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 			}
 			e->envp = tenvp;
 		} else
-			log_it("CRON", getpid(), "error", "can't set PATH");
+			log_it("CRON", getpid(), "error", "can't set PATH", 0);
 	}
 #endif /* LOGIN_CAP */
 	if (glue_strings(envstr, sizeof envstr, "LOGNAME",
@@ -319,7 +315,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 		}
 		e->envp = tenvp;
 	} else
-		log_it("CRON", getpid(), "error", "can't set LOGNAME");
+		log_it("CRON", getpid(), "error", "can't set LOGNAME", 0);
 #if defined(BSD) || defined(__linux)
 	if (glue_strings(envstr, sizeof envstr, "USER",
 			 pw->pw_name, '=')) {
@@ -329,7 +325,7 @@ load_entry(FILE *file, void (*error_func)(), struct passwd *pw, char **envp) {
 		}
 		e->envp = tenvp;
 	} else
-		log_it("CRON", getpid(), "error", "can't set USER");
+		log_it("CRON", getpid(), "error", "can't set USER", 0);
 #endif
 
 	Debug(DPARS, ("load_entry()...about to parse command\n"))
