@@ -30,15 +30,9 @@
  *
  */
 
+#ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
-#ifndef lint
-#if 0
-static char rcsid[] = "Id: popen.c,v 1.5 1994/01/15 20:43:43 vixie Exp";
-static char sccsid[] = "@(#)popen.c	5.7 (Berkeley) 2/14/89";
-//#else
-//__RCSID("$NetBSD: popen.c,v 1.9 2005/03/16 02:53:55 xtraeme Exp $");
 #endif
-#endif /* not lint */
 
 #include <cron.h>
 #include <signal.h>
@@ -110,7 +104,9 @@ cron_popen(char *program, const char *type, struct passwd *pw)
 		}
 
 		if (execvp(argv[0], argv) < 0) {
-			syslog(LOG_ERR, "CRON: Exec of (%s) failed: (%s)", program, strerror(errno));
+			int save_errno = errno;
+
+			log_it("CRON", getpid(), "EXEC FAILED", program, save_errno);
 			if (*type != 'r') {
 				while (0 != (out = read(STDIN, buf, PIPE_BUF))) {
 					if ((out == -1) && (errno != EINTR))
